This functions runs for every pair of dimensions
in the data the function plot_2D.
# S3 method for class 'vb_bmm'
plot(x, ...)A list of plots, that can be assembled in a unique figure
with other packages like ggpubr.
data(fit_mvbmm_example)
plot(fit_mvbmm_example)
#> Warning: The `x` argument of `as_tibble.matrix()` must have unique column names if
#> `.name_repair` is omitted as of tibble 2.0.0.
#> ℹ Using compatibility `.name_repair`.
#> ℹ The deprecated feature was likely used in the VIBER package.
#> Please report the issue at <https://github.com/caravagnalab/VIBER/issues>.
#> Warning: Using `size` aesthetic for lines was deprecated in ggplot2 3.4.0.
#> ℹ Please use `linewidth` instead.
#> ℹ The deprecated feature was likely used in the VIBER package.
#> Please report the issue at <https://github.com/caravagnalab/VIBER/issues>.
#> [[1]]
#>